define(['exports'], (function (exports) { 'use strict';

	function emptyFunction() {}

	console.log('lib');

	exports.emptyFunction = emptyFunction;

}));
